@@ -4,28 +4,15 @@
  */
 
 /*
- * Copyright (c) 2007-2009 Roy Marples <roy@marples.name>
+ * Copyright (c) 2007-2015 The OpenRC Authors.
+ * See the Authors file at the top-level directory of this distribution and
+ * https://github.com/OpenRC/openrc/blob/master/AUTHORS
  *
- * Redistribution and use in source and binary forms, with or without
- * modification, are permitted provided that the following conditions
- * are met:
- * 1. Redistributions of source code must retain the above copyright
- *    notice, this list of conditions and the following disclaimer.
- * 2. Redistributions in binary form must reproduce the above copyright
- *    notice, this list of conditions and the following disclaimer in the
- *    documentation and/or other materials provided with the distribution.
- *
- * THIS SOFTWARE IS PROVIDED BY THE AUTHOR AND CONTRIBUTORS ``AS IS'' AND
- * ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE
- * IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE
- * ARE DISCLAIMED.  IN NO EVENT SHALL THE AUTHOR OR CONTRIBUTORS BE LIABLE
- * FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL
- * DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS
- * OR SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION)
- * HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT
- * LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY
- * OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF
- * SUCH DAMAGE.
+ * This file is part of OpenRC. It is subject to the license terms in
+ * the LICENSE file found in the top-level directory of this
+ * distribution and at https://github.com/OpenRC/openrc/blob/master/LICENSE
+ * This file may not be copied, modified, propagated, or distributed
+ *    except according to the terms contained in the LICENSE file.
  */
 
 #include <sys/types.h>
@@ -60,13 +47,13 @@
 #  include <libutil.h>
 #endif
 
-#include "builtins.h"
 #include "einfo.h"
 #include "queue.h"
 #include "rc.h"
 #include "rc-misc.h"
 #include "rc-plugin.h"
 #include "rc-selinux.h"
+#include "_usage.h"
 
 #define PREFIX_LOCK	RC_SVCDIR "/prefix.lock"
 
@@ -74,7 +61,29 @@
 #define WAIT_TIMEOUT	60		/* seconds until we timeout */
 #define WARN_TIMEOUT	10		/* warn about this every N seconds */
 
-static const char *applet;
+const char *applet = NULL;
+const char *extraopts = "stop | start | restart | describe | zap";
+const char *getoptstring = "dDsSvl:Z" getoptstring_COMMON;
+const struct option longopts[] = {
+	{ "debug",      0, NULL, 'd'},
+	{ "dry-run",    0, NULL, 'Z'},
+	{ "ifstarted",  0, NULL, 's'},
+	{ "ifstopped",  0, NULL, 'S'},
+	{ "nodeps",     0, NULL, 'D'},
+	{ "lockfd",     1, NULL, 'l'},
+	longopts_COMMON
+};
+const char *const longopts_help[] = {
+	"set xtrace when running the script",
+	"show what would be done",
+	"only run commands when started",
+	"only run commands when stopped",
+	"ignore dependencies",
+	"fd of the exclusive lock from rc",
+	longopts_help_COMMON
+};
+const char *usagestring = NULL;
+
 static char *service, *runlevel, *ibsave, *prefix;
 static RC_DEPTREE *deptree;
 static RC_STRINGLIST *applet_list, *services, *tmplist;
@@ -381,6 +390,14 @@ svc_exec(const char *arg1, const char *arg2)
 		}
 
 		if (exists(RC_SVCDIR "/openrc-run.sh")) {
+			if (arg2)
+				einfov("Executing: %s %s %s %s %s",
+					RC_SVCDIR "/openrc-run.sh", RC_SVCDIR "/openrc-run.sh",
+					service, arg1, arg2);
+			else
+				einfov("Executing: %s %s %s %s",
+					RC_SVCDIR "/openrc-run.sh", RC_SVCDIR "/openrc-run.sh",
+					service, arg1);
 			execl(RC_SVCDIR "/openrc-run.sh",
 			    RC_SVCDIR "/openrc-run.sh",
 			    service, arg1, arg2, (char *) NULL);
@@ -388,6 +405,16 @@ svc_exec(const char *arg1, const char *arg2)
 			    service, strerror(errno));
 			_exit(EXIT_FAILURE);
 		} else {
+			if (arg2)
+				einfov("Executing: %s %s %s %s %s",
+					RC_LIBEXECDIR "/sh/openrc-run.sh",
+					RC_LIBEXECDIR "/sh/openrc-run.sh",
+			    	service, arg1, arg2);
+			else
+				einfov("Executing: %s %s %s %s",
+					RC_LIBEXECDIR "/sh/openrc-run.sh",
+					RC_LIBEXECDIR "/sh/openrc-run.sh",
+			    	service, arg1);
 			execl(RC_LIBEXECDIR "/sh/openrc-run.sh",
 			    RC_LIBEXECDIR "/sh/openrc-run.sh",
 			    service, arg1, arg2, (char *) NULL);
@@ -1076,31 +1103,7 @@ service_plugable(void)
 	return allow;
 }
 
-#include "_usage.h"
-#define getoptstring "dDsSvl:Z" getoptstring_COMMON
-#define extraopts "stop | start | restart | describe | zap"
-static const struct option longopts[] = {
-	{ "debug",      0, NULL, 'd'},
-	{ "dry-run",    0, NULL, 'Z'},
-	{ "ifstarted",  0, NULL, 's'},
-	{ "ifstopped",  0, NULL, 'S'},
-	{ "nodeps",     0, NULL, 'D'},
-	{ "lockfd",     1, NULL, 'l'},
-	longopts_COMMON
-};
-static const char *const longopts_help[] = {
-	"set xtrace when running the script",
-	"show what would be done",
-	"only run commands when started",
-	"only run commands when stopped",
-	"ignore dependencies",
-	"fd of the exclusive lock from rc",
-	longopts_help_COMMON
-};
-#include "_usage.c"
-
-int
-openrc_run(int argc, char **argv)
+int main(int argc, char **argv)
 {
 	bool doneone = false;
 	int retval, opt, depoptions = RC_DEP_TRACE;
@@ -1118,6 +1121,10 @@ openrc_run(int argc, char **argv)
 		exit(EXIT_FAILURE);
 	}
 
+	applet = basename_c(argv[0]);
+	if (strcmp(applet, "runscript") == 0)
+		ewarnv("runscript is deprecated, please use openrc-run instead.");
+
 	if (stat(argv[1], &stbuf) != 0) {
 		fprintf(stderr, "openrc-run `%s': %s\n",
 		    argv[1], strerror(errno));
@@ -1409,10 +1416,3 @@ openrc_run(int argc, char **argv)
 
 	return retval;
 }
-
-int
-runscript(int argc, char **argv)
-{
-	ewarnv("runscript is deprecated; please use openrc-run instead.");
-	return (openrc_run(argc, argv));
-}
