@@ -9,28 +9,15 @@
  */
 
 /*
- * Copyright (c) 2007-2009 Roy Marples <roy@marples.name>
+ * Copyright (c) 2007-2015 The OpenRC Authors.
+ * See the Authors file at the top-level directory of this distribution and
+ * https://github.com/OpenRC/openrc/blob/master/AUTHORS
  *
- * Redistribution and use in source and binary forms, with or without
- * modification, are permitted provided that the following conditions
- * are met:
- * 1. Redistributions of source code must retain the above copyright
- *    notice, this list of conditions and the following disclaimer.
- * 2. Redistributions in binary form must reproduce the above copyright
- *    notice, this list of conditions and the following disclaimer in the
- *    documentation and/or other materials provided with the distribution.
- *
- * THIS SOFTWARE IS PROVIDED BY THE AUTHOR AND CONTRIBUTORS ``AS IS'' AND
- * ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE
- * IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE
- * ARE DISCLAIMED.  IN NO EVENT SHALL THE AUTHOR OR CONTRIBUTORS BE LIABLE
- * FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL
- * DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS
- * OR SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION)
- * HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT
- * LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY
- * OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF
- * SUCH DAMAGE.
+ * This file is part of OpenRC. It is subject to the license terms in
+ * the LICENSE file found in the top-level directory of this
+ * distribution and at https://github.com/OpenRC/openrc/blob/master/LICENSE
+ * This file may not be copied, modified, propagated, or distributed
+ *    except according to the terms contained in the LICENSE file.
  */
 
 const char rc_copyright[] = "Copyright (c) 2007-2008 Roy Marples";
@@ -58,7 +45,6 @@ const char rc_copyright[] = "Copyright (c) 2007-2008 Roy Marples";
 #include <termios.h>
 #include <unistd.h>
 
-#include "builtins.h"
 #include "einfo.h"
 #include "queue.h"
 #include "rc.h"
@@ -67,6 +53,27 @@ const char rc_copyright[] = "Copyright (c) 2007-2008 Roy Marples";
 #include "rc-plugin.h"
 
 #include "version.h"
+#include "_usage.h"
+
+const char *extraopts = NULL;
+const char *getoptstring = "a:no:s:S" getoptstring_COMMON;
+const struct option longopts[] = {
+	{ "no-stop", 0, NULL, 'n' },
+	{ "override",    1, NULL, 'o' },
+	{ "service",     1, NULL, 's' },
+	{ "sys",         0, NULL, 'S' },
+	longopts_COMMON
+};
+const char * const longopts_help[] = {
+	"do not stop any services",
+	"override the next runlevel to change into\n"
+	"when leaving single user or boot runlevels",
+	"runs the service specified with the rest\nof the arguments",
+	"output the RC system type, if any",
+	longopts_help_COMMON
+};
+const char *usagestring = ""					\
+    "Usage: openrc [options] [<runlevel>]";
 
 #define INITSH                  RC_LIBEXECDIR "/sh/init.sh"
 #define INITEARLYSH             RC_LIBEXECDIR "/sh/init-early.sh"
@@ -276,9 +283,8 @@ open_shell(void)
 #ifdef __linux__
 	const char *sys = rc_sys();
 
-	/* VSERVER and OPENVZ systems cannot really drop to shells */
-	if (sys &&
-	    (strcmp(sys, "VSERVER") == 0 || strcmp(sys, "OPENVZ") == 0))
+	/* VSERVER systems cannot really drop to shells */
+	if (sys && strcmp(sys, RC_SYS_VSERVER) == 0)
 	{
 		execl("/sbin/halt", "/sbin/halt", "-f", (char *) NULL);
 		eerrorx("%s: unable to exec `/sbin/halt': %s",
@@ -724,31 +730,7 @@ handle_bad_signal(int sig)
 }
 #endif
 
-#include "_usage.h"
-#define usagestring ""					\
-    "Usage: openrc [options] [<runlevel>]"
-#define getoptstring "a:no:s:S" getoptstring_COMMON
-static const struct option longopts[] = {
-	{ "applet",   1, NULL, 'a' },
-	{ "no-stop", 0, NULL, 'n' },
-	{ "override",    1, NULL, 'o' },
-	{ "service",     1, NULL, 's' },
-	{ "sys",         0, NULL, 'S' },
-	longopts_COMMON
-};
-static const char * const longopts_help[] = {
-	"runs the applet specified by the next argument",
-	"do not stop any services",
-	"override the next runlevel to change into\n"
-	"when leaving single user or boot runlevels",
-	"runs the service specified with the rest\nof the arguments",
-	"output the RC system type, if any",
-	longopts_help_COMMON
-};
-#include "_usage.c"
-
-int
-main(int argc, char **argv)
+int main(int argc, char **argv)
 {
 	const char *bootlevel = NULL;
 	char *newlevel = NULL;
@@ -788,9 +770,6 @@ main(int argc, char **argv)
 	if (!applet)
 		eerrorx("arguments required");
 
-	/* Run our built in applets. If we ran one, we don't return. */
-	run_applets(argc, argv);
-
 	argc--;
 	argv++;
 
@@ -816,10 +795,6 @@ main(int argc, char **argv)
 		    longopts, (int *) 0)) != -1)
 	{
 		switch (opt) {
-		case 'a':
-			/* Do nothing, actual logic in run_applets, this
-			 * is a placeholder */
-			break;
 		case 'n':
 			nostop = true;
 			break;
@@ -855,6 +830,8 @@ main(int argc, char **argv)
 		}
 	}
 
+	if (strcmp(applet, "rc") == 0)
+		ewarnv("rc is deprecated, please use openrc instead.");
 	newlevel = argv[optind++];
 	/* To make life easier, we only have the shutdown runlevel as
 	 * nothing really needs to know that we're rebooting.
